@@ -123,15 +123,18 @@ class NlfffPlotD3CutCake():
         self.__cut_list.append(this_cut_dict)
 
     def run_cut(self,
-                fig_dict={"figsize":(6, 6)},
+                # https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.figure.html
+                fig_dict=dict(figsize=[6, 6],dpi=300.0),
+
+                view_dict=None,
 
                 # https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.show.html
                 is_show=True,
-                show_dict={"block":True},
+                show_dict=dict(block=True),
 
                 # https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.savefig.html
                 is_save=False,
-                save_dict={"fname":"./cut.png", "dpi":'figure'}
+                save_dict=dict(fname="./cut.png", dpi='figure')
                 ):
         """
         when you haven load data and add_cut ,
@@ -139,14 +142,24 @@ class NlfffPlotD3CutCake():
         :return: None
         """
         # computer shape
-                # set fig and you can use it outside like : d3_drawer.fig.XXX
+        # set fig and you can use it outside like : d3_drawer.fig.XXX
         self.fig = plt.figure(**fig_dict)
 
         # set draw view and you can use it outside like : d3_drawer.ax.view_init(40, -30)
         self.ax = self.fig.add_subplot(projection='3d')
         ## Set distance and angle view
-        self.ax.view_init(-40, 30)
-        self.ax.dist = 11
+        if view_dict is None:
+            elev=45
+            azim=45
+            dist=11
+        else:
+            elev=view_dict["elev"]
+            azim=view_dict["azim"]
+            dist=view_dict["dist"]
+        self.ax.view_init(elev, azim)
+        self.ax.dist = dist
+        # self.ax.view_init(-40, 30)
+        # self.ax.dist = 11
         self.data_hdf_dataset_name="Bxyz"
         ## Set labels and zticks
         self.ax.set(
